@@ -26,6 +26,7 @@ var HordeCore = {
     alarms: [],
     base: null,
     handlers: {},
+    jsfiles: [],
     loading: {},
     notify_handler: function(m) { HordeCore.showNotifications(m); },
     server_error: 0,
@@ -204,7 +205,7 @@ var HordeCore = {
             return;
         }
 
-        var r = resp.responseJSON;
+        var r = resp.responseJSON, head;
 
         if (r.reload) {
             if (r.reload === true) {
@@ -227,6 +228,20 @@ var HordeCore = {
         }
         this.server_error = 0;
 
+        if (r.jsfiles) {
+            head = $(document.head || document.getElementsByTagName('head')[0]);
+
+            r.jsfiles.each(function(j) {
+                if (this.jsfiles.indexOf(j) === -1) {
+                    head.insert(new Element('SCRIPT', {
+                        src: j,
+                        type: 'text/javascript'
+                    }));
+                    this.jsfiles.push(j);
+                }
+            }, this);
+        }
+
         if (r.tasks) {
             document.fire('HordeCore:runTasks', {
                 response: resp,
@@ -375,9 +390,7 @@ var HordeCore = {
                             });
                         }
                     }.bindAsEventListener(this))
-                    .observe('click', function(e) {
-                        e.stop();
-                    });
+                    .observe('click', Event.stop);
                     message.down('input[type=button]').observe('click', function(e) {
                         var ajax_params = $H({
                             alarm: alarm.id,
@@ -529,14 +542,31 @@ var HordeCore = {
 
     initHandler: function(type)
     {
+        var h, t;
+
         if (!this.handlers[type]) {
             switch (type) {
             case 'click':
             case 'dblclick':
-                this.handlers[type] = this.clickHandler.bindAsEventListener(this);
-                document.observe(type, this.handlers[type]);
+                h = this.clickHandler;
+                t = [ type ];
                 break;
+
+            case 'mousewheelY':
+                h = this.mousewheelYHandler;
+                t = ('onwheel' in document || (document.documentMode >= 9))
+                    ? [ 'wheel' ]
+                    : [ 'mousewheel', 'DomMouseScroll' ];
+                break;
+
+            default:
+                return;
             }
+
+            this.handlers[type] = h.bindAsEventListener(this);
+            t.each(function(e) {
+                document.observe(e, this.handlers[type]);
+            }, this);
         }
     },
 
@@ -562,6 +592,33 @@ var HordeCore = {
         }
     },
 
+    // 'HordeCore:mousewheelY' is fired on a vertical mouse wheel scroll event
+    // for every element up to the document root. The memo attribute is
+    // an integer: either -1 or 1.
+    //
+    // @since 2.11.0
+    mousewheelYHandler: function(e)
+    {
+        var delta = 0;
+
+        if (e.wheelDelta) {
+            delta = e.wheelDelta;
+        }
+        if (e.detail) {
+            delta = e.detail * -1;
+        }
+        if (e.deltaY) {
+            delta = e.deltaY * -1;
+        }
+        if (!Object.isUndefined(e.wheelDeltaY)) {
+            delta = e.wheelDeltaY;
+        }
+
+        if (delta) {
+            e.element().fire('HordeCore:mousewheelY', (delta > 0) ? 1 : -1);
+        }
+    },
+
     tasksHandler: function(e)
     {
         var t = e.tasks || {};
@@ -575,6 +632,14 @@ var HordeCore = {
         }
     },
 
+    onGrowlerDestroy: function(e)
+    {
+        var id = e.element().retrieve('alarm');
+        if (id) {
+            this.alarms = this.alarms.without(id);
+        }
+    },
+
     onDomLoad: function()
     {
         /* Determine base window. Need a try/catch block here since, if the
@@ -606,12 +671,7 @@ var HordeCore = {
 };
 
 document.observe('dom:loaded', HordeCore.onDomLoad.bind(HordeCore));
-document.observe('Growler:destroyed', function(e) {
-    var id = e.element().retrieve('alarm');
-    if (id) {
-        this.alarms = this.alarms.without(id);
-    }
-}.bindAsEventListener(HordeCore));
+document.observe('Growler:destroyed', HordeCore.onGrowlerDestroy.bindAsEventListener(HordeCore));
 document.observe('Growler:linkClick', function(e) {
     window.location.assign(e.memo.href);
 });
