@@ -173,28 +173,36 @@ class Horde_Core_Prefs_Ui
                     continue;
                 }
 
+                $todo = array();
+
                 if ($p['type'] == 'container') {
                     if (isset($p['value']) && is_array($p['value'])) {
-                        $cprefs = array_merge($cprefs, $p['value']);
+                        foreach ($p['value'] as $val) {
+                            $todo[$val] = $this->prefs[$val];
+                        }
                     }
                 } else {
-                    if (isset($p['requires'])) {
-                        foreach ($p['requires'] as $val) {
+                    $todo[$pref] = $p;
+                }
+
+                foreach ($todo as $k2 => $p2) {
+                    if (isset($p2['requires'])) {
+                        foreach ($p2['requires'] as $val) {
                             if (!$prefs->getValue($val)) {
                                 continue 2;
                             }
                         }
                     }
 
-                    if (isset($p['requires_nolock'])) {
-                        foreach ($p['requires_nolock'] as $val) {
+                    if (isset($p2['requires_nolock'])) {
+                        foreach ($p2['requires_nolock'] as $val) {
                             if ($prefs->isLocked($val)) {
                                 continue 2;
                             }
                         }
                     }
 
-                    $cprefs[] = $pref;
+                    $cprefs[] = $k2;
                 }
             }
         }
@@ -535,7 +543,7 @@ class Horde_Core_Prefs_Ui
 
                 case 'link':
                     if (isset($this->prefs[$pref]['img'])) {
-                        $t->set('img', Horde::img($this->prefs[$pref]['img'], $this->prefs[$pref]['desc'], array('class' => 'prefsLinkImg')));
+                        $t->set('img', Horde_Themes_Image::tag($this->prefs[$pref]['img'], array('alt' => $this->prefs[$pref]['desc'], 'attr' => array('class' => 'prefsLinkImg'))));
                     }
                     $t->set('url', isset($this->prefs[$pref]['url']) ? Horde::url($this->prefs[$pref]['url']) : $this->prefs[$pref]['xurl']);
                     if (isset($this->prefs[$pref]['target'])) {
@@ -706,10 +714,10 @@ class Horde_Core_Prefs_Ui
 
                 $t->set('prev', $prefs_url->copy()->add('group', $previous));
                 $t->set('prevlabel', htmlspecialchars($this->prefGroups[$previous]['label']));
-                $t->set('previcon', Horde::img('nav/left.png'));
+                $t->set('previcon', Horde_Themes_Image::tag('nav/left.png'));
                 $t->set('next', $prefs_url->copy()->add('group', $next));
                 $t->set('nextlabel', htmlspecialchars($this->prefGroups[$next]['label']));
-                $t->set('nexticon', Horde::img('nav/right.png'));
+                $t->set('nexticon', Horde_Themes_Image::tag('nav/right.png'));
             }
 
             echo $t->fetch($h_templates . '/prefs/begin.html');
@@ -948,6 +956,7 @@ class Horde_Core_Prefs_Ui
             }
         }
 
+        // TODO: Remove for H6
         if ($id == -2) {
             return;
         }
